summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStefano Lattarini <stefano.lattarini@gmail.com>2012-12-31 14:58:00 +0100
committerStefano Lattarini <stefano.lattarini@gmail.com>2012-12-31 15:11:05 +0100
commitab76d22dd759153542c2133fbc99c591e17e6791 (patch)
treef360ca319011c175950d6b8a2245ddc5fd644788
parent78e1c8e561d71ae70b2d014a758502c9dc523a95 (diff)
parent51defae0a5af847d6c69de685b8997ae9178584d (diff)
downloadautomake-ab76d22dd759153542c2133fbc99c591e17e6791.tar.gz
Merge branch 'master' into ng/master
* master: docs: adjust comment w.r.t. recent tests renaming tests: some more renames for texinfo tests tests: enhance and tweak some texinfo tests tests: remove a redundant texinfo test tests: don't list a removed tests in XFAIL_TESTS tests: more explicative names for some tests cleanup: drop a redundant %?FIRST% transform maint: state when compatibility cruft should be removed or warned about + Non-trivial extra edits * t/txinfo-other-suffixes.sh: Remove, Automake-NG only supports '.texi' ad suffix for Texinfo files. * t/txinfo-without-info-suffix.sh: Remove, Automake-NG doesn't support generating suffix-less info files. * t/txinfo-no-repeated-targets.sh: Remove, superseded by test 't/txinfo-rules-once.sh' (see [ng] commit v1.12.1-416-gd5459b9). * t/txinfo-dvi-recurs.sh: Remove, basically an obsolete grepping test (as was the test 'txinfo10.sh' this was renamed from; see [ng] commit v1.12.2-887-gb80d8d2). Signed-off-by: Stefano Lattarini <stefano.lattarini@gmail.com>
-rw-r--r--doc/automake-ng.texi2
-rw-r--r--lib/Automake/Options.pm1
-rw-r--r--m4/obsolete-err.m44
-rwxr-xr-xt/txinfo-absolute-srcdir-pr408.sh (renamed from t/txinfo26.sh)0
-rwxr-xr-xt/txinfo-add-missing-and-dist.sh (renamed from t/txinfo8.sh)0
-rwxr-xr-xt/txinfo-bsd-make-recurs.sh (renamed from t/txinfo32.sh)0
-rwxr-xr-xt/txinfo-clean.sh (renamed from t/txinfo33.sh)0
-rwxr-xr-xt/txinfo-info-in-srcdir.sh (renamed from t/txinfo16.sh)0
-rwxr-xr-xt/txinfo-makeinfo-error-no-clobber.sh (renamed from t/txinfo20.sh)0
-rwxr-xr-xt/txinfo-many-output-formats.sh (renamed from t/txinfo21.sh)0
-rwxr-xr-xt/txinfo-no-extra-dist.sh (renamed from t/txinfo2.sh)31
-rwxr-xr-xt/txinfo-no-installinfo.sh (renamed from t/txinfo27.sh)0
-rwxr-xr-xt/txinfo-override-infodeps.sh (renamed from t/txinfo29.sh)0
-rwxr-xr-xt/txinfo-override-texinfo-tex.sh (renamed from t/txinfo22.sh)0
-rwxr-xr-xt/txinfo-setfilename-repeated.sh (renamed from t/txinfo17.sh)0
-rwxr-xr-xt/txinfo-setfilename-suffix-strip.sh (renamed from t/txinfo31.sh)8
-rwxr-xr-xt/txinfo-subdir-pr343.sh (renamed from t/txinfo13.sh)7
-rwxr-xr-xt/txinfo-tex-dist.sh (renamed from t/txinfo.sh)0
-rwxr-xr-xt/txinfo-unrecognized-info-suffix.sh (renamed from t/txinfo4.sh)0
-rwxr-xr-xt/txinfo-vtexi.sh (renamed from t/vtexi.sh)0
-rwxr-xr-xt/txinfo-vtexi2.sh (renamed from t/vtexi2.sh)0
-rwxr-xr-xt/txinfo-vtexi3.sh (renamed from t/vtexi3.sh)4
-rwxr-xr-xt/txinfo-vtexi4.sh (renamed from t/vtexi4.sh)4
-rwxr-xr-xt/txinfo7.sh33
24 files changed, 40 insertions, 54 deletions
diff --git a/doc/automake-ng.texi b/doc/automake-ng.texi
index 69d1a9c14..aa4b14c99 100644
--- a/doc/automake-ng.texi
+++ b/doc/automake-ng.texi
@@ -7868,7 +7868,7 @@ passed to @code{makeinfo} when building @file{.info} files; and
@samp{$(AM_MAKEINFOHTMLFLAGS)} is used when building @file{.html}
files.
-@c Keep in sync with txinfo21.sh
+@c Keep in sync with txinfo-many-output-formats.sh
For instance, the following setting can be used to obtain one single
@file{.html} file per manual, without node separators.
@example
diff --git a/lib/Automake/Options.pm b/lib/Automake/Options.pm
index 77e9cbdbd..a3b8193a6 100644
--- a/lib/Automake/Options.pm
+++ b/lib/Automake/Options.pm
@@ -309,6 +309,7 @@ sub _process_option_list (\%@)
{
set_strictness ($_);
}
+ # TODO: Remove this special check in Automake 1.15.
elsif ($_ eq 'cygnus')
{
error $where, "support for Cygnus-style trees has been removed";
diff --git a/m4/obsolete-err.m4 b/m4/obsolete-err.m4
index 77dab8c95..875434262 100644
--- a/m4/obsolete-err.m4
+++ b/m4/obsolete-err.m4
@@ -8,22 +8,26 @@
# gives unlimited permission to copy and/or distribute it,
# with or without modifications, as long as this notice is preserved.
+dnl TODO: Remove in Automake 1.15.
AC_DEFUN([AM_CONFIG_HEADER],
[AC_FATAL(['$0': this macro is obsolete.
You should use the 'AC][_CONFIG_HEADERS' macro instead.])])
+dnl TODO: Remove in Automake 1.15.
AC_DEFUN([AM_PROG_CC_STDC],
[AC_FATAL(['$0': this macro is obsolete.
You should simply use the 'AC][_PROG_CC' macro instead.
Also, your code should no longer depend upon 'am_cv_prog_cc_stdc',
but upon 'ac_cv_prog_cc_stdc'.])])
+dnl TODO: Remove in Automake 1.16.
AC_DEFUN([AM_PROG_MKDIR_P],
[AC_FATAL(['$0': this macro is obsolete.
You should simply use the 'AC][_PROG_MKDIR_P' macro instead, and
use '$(MKDIR_P)' instead of '$(mkdir_p)' in your Makefile.am
files.])])
+dnl TODO: Remove in Automake 1.14.
AC_DEFUN([AM_C_PROTOTYPES],
[AC_FATAL([automatic de-ANSI-fication support has been removed])])
AU_DEFUN([fp_C_PROTOTYPES], [AM_C_PROTOTYPES])
diff --git a/t/txinfo26.sh b/t/txinfo-absolute-srcdir-pr408.sh
index 268f81880..268f81880 100755
--- a/t/txinfo26.sh
+++ b/t/txinfo-absolute-srcdir-pr408.sh
diff --git a/t/txinfo8.sh b/t/txinfo-add-missing-and-dist.sh
index 4df666173..4df666173 100755
--- a/t/txinfo8.sh
+++ b/t/txinfo-add-missing-and-dist.sh
diff --git a/t/txinfo32.sh b/t/txinfo-bsd-make-recurs.sh
index c9d7d83da..c9d7d83da 100755
--- a/t/txinfo32.sh
+++ b/t/txinfo-bsd-make-recurs.sh
diff --git a/t/txinfo33.sh b/t/txinfo-clean.sh
index 47f403893..47f403893 100755
--- a/t/txinfo33.sh
+++ b/t/txinfo-clean.sh
diff --git a/t/txinfo16.sh b/t/txinfo-info-in-srcdir.sh
index 11f7dea57..11f7dea57 100755
--- a/t/txinfo16.sh
+++ b/t/txinfo-info-in-srcdir.sh
diff --git a/t/txinfo20.sh b/t/txinfo-makeinfo-error-no-clobber.sh
index a71fcf9c5..a71fcf9c5 100755
--- a/t/txinfo20.sh
+++ b/t/txinfo-makeinfo-error-no-clobber.sh
diff --git a/t/txinfo21.sh b/t/txinfo-many-output-formats.sh
index 00ceeb1cc..00ceeb1cc 100755
--- a/t/txinfo21.sh
+++ b/t/txinfo-many-output-formats.sh
diff --git a/t/txinfo27.sh b/t/txinfo-no-installinfo.sh
index f1e8791ba..f1e8791ba 100755
--- a/t/txinfo27.sh
+++ b/t/txinfo-no-installinfo.sh
diff --git a/t/txinfo29.sh b/t/txinfo-override-infodeps.sh
index b21967892..b21967892 100755
--- a/t/txinfo29.sh
+++ b/t/txinfo-override-infodeps.sh
diff --git a/t/txinfo22.sh b/t/txinfo-override-texinfo-tex.sh
index d337d6ec1..d337d6ec1 100755
--- a/t/txinfo22.sh
+++ b/t/txinfo-override-texinfo-tex.sh
diff --git a/t/txinfo17.sh b/t/txinfo-setfilename-repeated.sh
index 0d12b053a..0d12b053a 100755
--- a/t/txinfo17.sh
+++ b/t/txinfo-setfilename-repeated.sh
diff --git a/t/txinfo31.sh b/t/txinfo-setfilename-suffix-strip.sh
index 567e28f40..8526d5381 100755
--- a/t/txinfo31.sh
+++ b/t/txinfo-setfilename-suffix-strip.sh
@@ -14,7 +14,8 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-# Make sure file extensions are matched correctly.
+# Make sure file extensions are matched correctly in the code
+# parsing texi files for @setfilename declarations.
# Report from Eric Dorland.
. test-init.sh
@@ -25,5 +26,8 @@ cat >bar.texi <<EOF
EOF
$ACLOCAL
-$AUTOCONF
$AUTOMAKE --add-missing
+
+$EGREP '[ /]bar-1\.9\.info( |$)' Makefile.in
+
+:
diff --git a/t/txinfo13.sh b/t/txinfo-subdir-pr343.sh
index 374c44a27..0ecb4bff2 100755
--- a/t/txinfo13.sh
+++ b/t/txinfo-subdir-pr343.sh
@@ -15,8 +15,6 @@
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Check for subdir Texinfo (PR/343).
-# Also make sure we do not distribute too much foo.info* files (Report
-# from Vincent Lefevre).
required='makeinfo tex texi2dvi'
. test-init.sh
@@ -29,8 +27,6 @@ subdir_main_TEXINFOS = subdir/inc.texi
installcheck-local:
test -f "$(infodir)/main.info"
-check-local:
- test ! -f $(srcdir)/subdir/main.info.bak
END
mkdir subdir
@@ -50,8 +46,6 @@ cat > subdir/inc.texi << 'END'
I'm included.
END
-touch subdir/main.info.bak
-
$ACLOCAL
$AUTOMAKE --add-missing
$AUTOCONF
@@ -62,6 +56,5 @@ cd build
$MAKE distcheck
test -f ../subdir/main.info
test ! -e subdir/main.info
-test -f ../subdir/main.info.bak
:
diff --git a/t/txinfo.sh b/t/txinfo-tex-dist.sh
index 5d04cd5c5..5d04cd5c5 100755
--- a/t/txinfo.sh
+++ b/t/txinfo-tex-dist.sh
diff --git a/t/txinfo4.sh b/t/txinfo-unrecognized-info-suffix.sh
index 6784d034e..6784d034e 100755
--- a/t/txinfo4.sh
+++ b/t/txinfo-unrecognized-info-suffix.sh
diff --git a/t/vtexi.sh b/t/txinfo-vtexi.sh
index 6b7ab54df..6b7ab54df 100755
--- a/t/vtexi.sh
+++ b/t/txinfo-vtexi.sh
diff --git a/t/vtexi2.sh b/t/txinfo-vtexi2.sh
index 14b3e4ded..14b3e4ded 100755
--- a/t/vtexi2.sh
+++ b/t/txinfo-vtexi2.sh
diff --git a/t/vtexi3.sh b/t/txinfo-vtexi3.sh
index 0b000a381..09e74bb55 100755
--- a/t/vtexi3.sh
+++ b/t/txinfo-vtexi3.sh
@@ -17,8 +17,8 @@
# Check that vers*.texi files are automatically created and distributed
# if @included into a texi source. Also check that they correctly contain
# the @values definitions they are advertised to.
-# See also the related test 'vtexi4.sh', which does similar checks, but
-# for version.texi only, and requires makeinfo, tex and texi2dvi.
+# See also the related test 'txinfo-vtexi4.sh', which does similar checks,
+# but for version.texi only, and requires makeinfo, tex and texi2dvi.
. test-init.sh
diff --git a/t/vtexi4.sh b/t/txinfo-vtexi4.sh
index 8f64b43d1..e5d8deec0 100755
--- a/t/vtexi4.sh
+++ b/t/txinfo-vtexi4.sh
@@ -17,8 +17,8 @@
# Check that the version.texi file is automatically created and distributed
# if @included into a texi source. Also check that is correctly defined
# @values definitions it is advertised to.
-# See also the related test 'vtexi3.sh', which does similar checks, but
-# for more vers*.texi files, and does not require makeinfo, tex and
+# See also the related test 'txinfo-vtexi4.sh', which does similar checks,
+# but for more vers*.texi files, and does not require makeinfo, tex and
# texi2dvi.
required='makeinfo tex texi2dvi grep-nonprint'
diff --git a/t/txinfo7.sh b/t/txinfo7.sh
deleted file mode 100755
index 8d720547b..000000000
--- a/t/txinfo7.sh
+++ /dev/null
@@ -1,33 +0,0 @@
-#! /bin/sh
-# Copyright (C) 1998-2012 Free Software Foundation, Inc.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2, or (at your option)
-# any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
-
-# Test to make sure texinfo.tex correctly installed by -a. Bug report
-# by Per Cederqvist.
-
-. test-init.sh
-
-cat > Makefile.am << 'END'
-info_TEXINFOS = textutils.texi
-END
-
-echo '@setfilename textutils.info' > textutils.texi
-
-$ACLOCAL
-$AUTOMAKE -a
-
-test -f texinfo.tex
-
-:
diff --git a/t/txinfo2.sh b/t/txinfo-no-extra-dist.sh
index f5664885b..177007c71 100755
--- a/t/txinfo2.sh
+++ b/t/txinfo-no-extra-dist.sh
@@ -14,8 +14,8 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Test to ensure that a ".info~" file doesn't end up in the
# distribution. Bug report from Greg McGary.
. test-init.sh
@@ -24,22 +24,39 @@ AC_OUTPUT
END
cat > Makefile.am << 'END'
-info_TEXINFOS = textutils.texi
-.PHONY: test
-test:
+info_TEXINFOS = textutils.texi subdir/main.texi
+test: distdir
@echo am.dist.all-files = $(am.dist.all-files)
- case '$(am.dist.all-files)' in *'~'*) exit 1;; *) exit 0;; esac
+ @case '$(am.dist.all-files)' in \
+ *'~'*|*'.bak'*) exit 1;; \
+ *) exit 0;; \
+ esac
+ @st=0; \
+ find $(distdir) | grep '~' && st=1; \
+ find $(distdir) | grep '\.bak' && st=1; \
+ exit $$st
+PHONY: test
END
: > texinfo.tex
+mkdir subdir
echo '@setfilename textutils.info' > textutils.texi
-: > textutils.info~
+echo '@setfilename main.info' > subdir/main.texi
$ACLOCAL
$AUTOCONF
$AUTOMAKE
./configure
+: > textutils.info
+: > subdir/main.info
+: > textutils.info~
+: > textutils.info.bak
+: > subdir/main.info~
+: > subdir/main.info.bak
$MAKE test
+$MAKE maintainer-clean
+test -f subdir/main.info~
+test -f subdir/main.info.bak
:
@@ -14,8 +14,8 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-# Test to ensure that a ".info~" file doesn't end up in the
-# distribution. Bug report from Greg McGary.
+# Test to ensure that a ".info~" or ".info.bak" file doesn't end up
+# in the distribution. Bug report from Greg McGary.
. test-init.sh